@@ -3,7 +3,6 @@
 from typing import Optional, ClassVar, Literal, Union, List
 import abc
 import logging
-import requests
 from ..record import Record, check_error, XmlData
 from lxml import etree
 from copy import deepcopy
@@ -39,13 +38,16 @@ class Bib(Record, metaclass=abc.ABCMeta):
         super().__init__(zone, env, data)
         self.mms_id = mms_id
         self.area = 'Bibs'
+        self.format = 'xml'
 
     def _fetch_data(self) -> Optional[XmlData]:
         """Fetch bibliographic data and store it in the "data" attribute as an Etree element
 
         :return: None or :class:`almapiwrapper.record.XmlData` object
         """
-        r = requests.get(f'{self.api_base_url_bibs}/{self.mms_id}', headers=self._get_headers(data_format='xml'))
+        r = self._api_call('get',
+                           f'{self.api_base_url_bibs}/{self.mms_id}',
+                           headers=self._get_headers())
 
         if r.ok is True:
             logging.info(f'{repr(self)}: bib data available')
@@ -85,9 +87,10 @@ class Bib(Record, metaclass=abc.ABCMeta):
 
         :return: Bib
         """
-        r = requests.put(f'{self.api_base_url_bibs}/{self.mms_id}',
-                         data=bytes(self),
-                         headers=self._get_headers(data_format='xml'))
+        r = self._api_call('put',
+                           f'{self.api_base_url_bibs}/{self.mms_id}',
+                           data=bytes(self),
+                           headers=self._get_headers())
 
         if r.ok is True:
             self.data = XmlData(r.content)
@@ -211,9 +214,9 @@ class IzBib(Bib):
         nz_mms_id = self.mms_id
 
         # Fetch data from nz mms_id
-        r = requests.get(f'{self.api_base_url_bibs}',
-                         params={'nz_mms_id': nz_mms_id},
-                         headers=self._get_headers(data_format='xml'))
+        r = self._api_call('get', f'{self.api_base_url_bibs}',
+                           params={'nz_mms_id': nz_mms_id},
+                           headers=self._get_headers())
 
         if r.ok is True:
             # Data found in the IZ for the NZ MMS ID provided
@@ -235,10 +238,10 @@ class IzBib(Bib):
         """
         nz_mms_id = self.mms_id
 
-        r = requests.post(f'{self.api_base_url_bibs}',
-                          params={'from_nz_mms_id': nz_mms_id},
-                          data='<bib/>',
-                          headers=self._get_headers(data_format='xml'))
+        r = self._api_call('post', f'{self.api_base_url_bibs}',
+                           params={'from_nz_mms_id': nz_mms_id},
+                           data='<bib/>',
+                           headers=self._get_headers())
 
         if r.ok is True:
             logging.info(f'Record {repr(self)} copied from NZ record {nz_mms_id}')
@@ -278,17 +281,19 @@ class IzBib(Bib):
             self.delete_holdings(force=True)
 
         # Unlink NZ and IZ record
-        r = requests.post(f'{self.api_base_url_bibs}/{self.mms_id}',
-                          params={'op': 'unlink_from_nz'},
-                          data='<bib/>',
-                          headers=self._get_headers(data_format='xml'))
+        r = self._api_call('post',
+                           f'{self.api_base_url_bibs}/{self.mms_id}',
+                           params={'op': 'unlink_from_nz'},
+                           data='<bib/>',
+                           headers=self._get_headers())
 
         # Delete record
         if r.ok is True:
             logging.info(f'{repr(self)} unlinked from NZ')
 
-            r = requests.delete(f'{self.api_base_url_bibs}/{self.mms_id}',
-                                headers=self._get_headers(data_format='xml'), params={'override': 'true'})
+            r = self._api_call('delete',
+                               f'{self.api_base_url_bibs}/{self.mms_id}',
+                               headers=self._get_headers(), params={'override': 'true'})
             if r.ok is True:
                 logging.info(f'{repr(self)} deleted')
                 return
@@ -308,8 +313,9 @@ class IzBib(Bib):
         if self._holdings is not None:
             return self._holdings
 
-        r = requests.get(f'{self.api_base_url_bibs}/{self.mms_id}/holdings',
-                         headers=self._get_headers(data_format='xml'))
+        r = self._api_call('get',
+                           f'{self.api_base_url_bibs}/{self.mms_id}/holdings',
+                           headers=self._get_headers())
         root = etree.fromstring(r.content, parser=self.parser)
         holdings_data = root.findall('.//holding')
 
@@ -404,9 +410,10 @@ class NzBib(Bib):
         """
 
         # Delete record
-        r = requests.delete(f'{self.api_base_url_bibs}/{self.mms_id}',
-                            params={'override': 'true' if force is True else 'false'},
-                            headers=self._get_headers(data_format='xml'))
+        r = self._api_call('delete',
+                           f'{self.api_base_url_bibs}/{self.mms_id}',
+                           params={'override': 'true' if force is True else 'false'},
+                           headers=self._get_headers())
 
         if r.ok is True:
             logging.info(f'{repr(self)} deleted')
@@ -423,7 +430,10 @@ class NzBib(Bib):
             method will be skipped.
         """
 
-        r = requests.post(f'{self.api_base_url_bibs}', headers=self._get_headers(data_format='xml'), data=bytes(self))
+        r = self._api_call('post',
+                           f'{self.api_base_url_bibs}',
+                           headers=self._get_headers(),
+                           data=bytes(self))
 
         if r.ok is True:
             self.data = XmlData(r.content)
@@ -432,3 +442,20 @@ class NzBib(Bib):
 
         else:
             self._handle_error(r, f'unable to create NZ bib record')
+
+
+def fetch_nz_bibs(q: str, env: Literal['P', 'S'] = 'P') -> List[NzBib]:
+    """
+
+    :param q: sru query
+    :param env: environment of the entity: 'P' for production and 'S' for sandbox
+    :return: list of :class:`almapiwrapper.record.NzBib`
+    """
+    pass
+#     url = 'https://swisscovery.slsp.ch/view/sru/41SLSP_NETWORK'
+#     r = Record._api_call('get',
+#                          url,
+#                          params={'query': q,
+#                                  'version': '1.2',
+#                                  'operation': 'searchRetrieve'})
+#     return r
