@@ -1,6 +1,4 @@
 import unittest
-import sys
-import os
 import time
 from almapiwrapper.users import User, NewUser, fetch_users
 from almapiwrapper.record import JsonData
@@ -46,4 +44,4 @@ class TestFetchUsers(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
